summaryrefslogtreecommitdiffstats
path: root/byterun/backtrace.c
diff options
context:
space:
mode:
Diffstat (limited to 'byterun/backtrace.c')
-rw-r--r--byterun/backtrace.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/byterun/backtrace.c b/byterun/backtrace.c
index 7b8ddca88..b5efdc3db 100644
--- a/byterun/backtrace.c
+++ b/byterun/backtrace.c
@@ -118,7 +118,7 @@ void caml_stash_backtrace(value exn, code_t pc, value * sp)
}
/* Read the debugging info contained in the current bytecode executable.
- Return a Caml array of Caml lists of debug_event records in "events",
+ Return an OCaml array of OCaml lists of debug_event records in "events",
or Val_false on failure. */
#ifndef O_BINARY
@@ -274,7 +274,7 @@ CAMLexport void caml_print_exception_backtrace(void)
}
}
/* Convert the backtrace to a data structure usable from Caml */
CAMLprim value caml_get_exception_backtrace(value unit)
{
@@ -274,7 +274,7 @@ CAMLexport void caml_print_exception_backtrace(void)
}
}
-/* Convert the backtrace to a data structure usable from Caml */
+/* Convert the backtrace to a data structure usable from OCaml */
CAMLprim value caml_get_exception_backtrace(value unit)
{